Changelog
=========


0.1.3 (2024-06-26)
------------------
- Add tool.isort option section. [sdementen]
- Cleanup. [sdementen]
- Isort/black generated schemas + remove unused imports. [sdementen]
- Print path where schemas exported. [sdementen]
- Rename Base to DeclarativeBase to avoid name shadowing. [sdementen]
- Extend tests. [sdementen]
- Reformat file. [sdementen]
- Omit from coverage template .py files. [sdementen]
- Reorganise modules. [sdementen]
- Fix bug in camelize. [sdementen]
- Add commands to make.py to mimic Makefile. [sdementen]


0.1.2 (2024-06-25)
------------------
- During tests, path_schemas to point to tmp folder. [sdementen]
- Use setup.cfg instead of .flake8. [sdementen]
- Add blank in some gnucash book name for testing purposes. [sdementen]
- Mypy fixes. [sdementen]
- Add make CLI implemented in python. [sdementen]
- Fix flake8 issues. [sdementen]
- Fix linter issues. [sdementen]
- Adapt linter to use 140 charts per line. [sdementen]
- Remove the rename_project.yml CI action. [sdementen]
- Add sqlacodegen_v2 as dependency. [sdementen]
- Update setup.py with maturity and description. [sdementen]
- Add some simple tests. [sdementen]
- Add example in README.md. [sdementen]
- Add first working code. [sdementen]
- Add data folder with sample of gnucash sqlite books. [sdementen]


0.1.1 (2024-06-24)
------------------
- Clean up repo generated from template. [Sébastien de Menten]
- Bump softprops/action-gh-release from 1 to 2. [dependabot[bot]]
- Bump codecov/codecov-action from 3 to 4. [dependabot[bot]]
- Bump stefanzweifel/git-auto-commit-action from 4 to 5.
  [dependabot[bot]]
- Bump actions/checkout from 3 to 4. [dependabot[bot]]
- Update main.yml. [sdementen]

  use python -m pip instead of pip directly
- Bump actions/setup-python from 4 to 5. [dependabot[bot]]
- ✅ Ready to clone and code. [sdementen]
- Initial commit. [sdementen]


